==> prestashop-1.3.2.3.tbz: www/prestashop/translations/es/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF_invoicee0036b67b754e9f6442f9f9e6b200c33'] = 'Devolución nº ';
$_LANGPDF['PDF_invoice77c3e447f60541a1c346a08134078c7f'] = 'Vale de compra nº ';
$_LANGPDF['PDF_invoicecb5efbba6a6babef9082ca6976928ca7'] = 'Albarán nº ';
$_LANGPDF['PDF_invoicefe4da50838bb10dcbf1bf8dcd9b12ab5'] = 'Factura nº ';
$_LANGPDF['PDF_invoiceba160acb58001c904c57507da3689265'] = 'Pedido n°';
$_LANGPDF['PDF_invoice8dae339c20973fe3fcdeb5f2e8e8f894'] = 'La versión electrónica de este vale de descuento está disponible en su cuenta. Para acceder a ella, identifíquese en';
$_LANGPDF['PDF_invoice15b57bef332e7e0327d89fe93711a954'] = 'La versión electrónica de esta factura está disponible en su cuenta. Para acceder a ella, identifíquese en';
$_LANGPDF['PDF_invoicef14e57cfbfd08615bbb665cb803f46b1'] = 'nuestra Web usando su dirección de correo electrónico y contraseña (que creó cuando realizó su primer pedido).';
$_LANGPDF['PDF_invoice808a04117534f9dfb63b9accd7efc609'] = 'Oficinas:';
$_LANGPDF['PDF_invoice2babe53026309ed1bc4d26626dbaf9b3'] = 'Detalles:';
$_LANGPDF['PDF_invoicea54cedc1e053a70d4a6319feccf531ca'] = 'TELÉFONO:';
$_LANGPDF['PDF_invoiced98a07f84921b24ee30f86fd8cd85c3c'] = 'de';
$_LANGPDF['PDF_invoice88be9ea838e21273267409d76af3b284'] = 'Hemos accedido a su solicitud de devolución.';
$_LANGPDF['PDF_invoicee209d63b7260d6ce2c7873df4c2ee73c'] = 'Le recordamos que debemos recibir su devolución antes de';
$_LANGPDF['PDF_invoice1926fda32a52ec84f205a65b98f8bbb8'] = 'días desde el momento en que recibió su pedido.';
$_LANGPDF['PDF_invoice3d2f834cf879baebfdbe52c1c14d9d53'] = 'Listado de artículos devueltos:';
$_LANGPDF['PDF_invoice9fad4fa5f3fa5caad9b506bbdd9f35d4'] = 'Referencia de devolución:';
$_LANGPDF['PDF_invoicefb902bc4807c307b9309f2b528b96f2b'] = 'RET';
$_LANGPDF['PDF_invoice80fb5b9230a258ff2e249f1148e726fc'] = 'Gracias por incluir este número en su paquete de devolución.';
$_LANGPDF['PDF_invoicefbbd47b7e45c0ad3fe0bf70539b5a2d4'] = 'RECUERDE:';
$_LANGPDF['PDF_invoicea3852e23346f6f1e29e1683991690af3'] = '- Todos los artículos deben devolverse en su embalaje original en buen estado y sin haber sido usados.';
$_LANGPDF['PDF_invoice0e9a828e54995e48083a072205493fb4'] = '- Por favor,  imprima este documento e introdúzcalo en su envío.';
$_LANGPDF['PDF_invoicead500469c8dc258dcebb89c9efe15de7'] = '- El paquete debe enviarse a la siguiente dirección:';
$_LANGPDF['PDF_invoice8a060230ab24c7f6a92f3e2b06ed171a'] = 'Una vez recibamos su envío, le informaremos por correo electrónico y procederemos al reembolso de su dinero.';
$_LANGPDF['PDF_invoice2d0620950a4d96ae301ba7a98e528714'] = 'Indíquenos cualquier pregunta que le surja.';
$_LANGPDF['PDF_invoice25e12a86579549b9f88117615eb05e4b'] = 'Si no se respetan las condiciones de devolución,';
$_LANGPDF['PDF_invoicec896fe3f3895e8ef54194eec601b8f3c'] = 'nos reservamos el derecho de rechazar su envío o el reembolso.';
$_LANGPDF['PDF_invoiceb5a7adde1af5c87d7fd797b6245c2a39'] = 'Descripción';
$_LANGPDF['PDF_invoice63d5049791d9d79d86e9a108b0a999ca'] = 'Referencia';
$_LANGPDF['PDF_invoice03ab340b3f99e03cff9e84314ead38c0'] = 'Cant.';
$_LANGPDF['PDF_invoice396124314c5fd1fa5bf463274896dc80'] = 'No se ha definido ningún método de precio para este grupo';
$_LANGPDF['PDF_invoice065ab3a28ca4f16f55f103adc7d0226f'] = 'Entrega';
$_LANGPDF['PDF_invoice6bdf2efe1a99072849d4e87baee37dbe'] = 'Facturación';
$_LANGPDF['PDF_invoice60da3bd6867e3952ef0057a0772ea885'] = 'id del impuesto';
$_LANGPDF['PDF_invoiced1228f5476d15142b1358ae4b5fa2454'] = 'Pedido nº ';
$_LANGPDF['PDF_invoicef8617a92ba0a0a4eabee724eab7c9f48'] = 'Transportista:';
$_LANGPDF['PDF_invoicec1f6368d15f7c13c4e5e8f70c68c747f'] = 'Modo de pago:';
$_LANGPDF['PDF_invoicea3a79b28bc45b7fd393effd056b917e1'] = 'Fecha de envío:';
$_LANGPDF['PDF_invoice115dfa9ced2cf136ae677b9a389a5e60'] = 'paquete regalo';
$_LANGPDF['PDF_invoice2370a4958c4ebe6d6c8045cd49a6b392'] = 'Total productos sin IVA';
$_LANGPDF['PDF_invoiceebaee01719541f61281c16ba22ebbfde'] = 'Total productos (IVA incluido)';
$_LANGPDF['PDF_invoicea0eb2cd0b3deb5444102e9a82edae11e'] = 'Total productos';
$_LANGPDF['PDF_invoicef3e545fccad720e197b9ca3b8b658440'] = 'Total descuentos (IVA incluido)';
$_LANGPDF['PDF_invoice7a5b34426b4672759796f035bbc2674e'] = 'Total embalaje';
$_LANGPDF['PDF_invoicef4e8b53a114e5a17d051ab84d326cae5'] = 'Gastos de envío';
$_LANGPDF['PDF_invoice96b0141273eabab320119c467cdcaf17'] = 'Total';
$_LANGPDF['PDF_invoice54732c5d0a3f0d597312b0ee55d71fca'] = '(IVA incluido)';
$_LANGPDF['PDF_invoiceac5831c7ec2fed92c7bb73e9962003a4'] = '(sin IVA)';
$_LANGPDF['PDF_invoice7d3548c5b974fa710296c1b3f5564753'] = 'Ecotasa';
$_LANGPDF['PDF_invoiceafd42dfebce46ec93972b2e0cbb8b83f'] = 'Precio Un.';
$_LANGPDF['PDF_invoicec2808546f3e14d267d798f4e0e6f102e'] = 'Personalizado';
$_LANGPDF['PDF_invoicea1e7379abfdbc3b8e03506e5489c6110'] = 'Descuento:';
$_LANGPDF['PDF_invoice42c26bf38ece1dcd27aca8c6f8c076ed'] = 'Desglose IVA';
$_LANGPDF['PDF_invoicea7fa76ae71664800f8994ad52581e3c2'] = '% IVA';
$_LANGPDF['PDF_invoicecd6576cc33506a6c44e2debbde5c14d9'] = 'Total sin IVA';
$_LANGPDF['PDF_invoiceb602e0d0c6a72053d0a5be60cb2f8126'] = 'Total IVA';
$_LANGPDF['PDF_invoiceae5c2883df7651730799e1036984a6a3'] = 'Total IVA incluído';
$_LANGPDF['PDF_invoice068f80c7519d0528fb08e82137a72131'] = 'Artículos';
$_LANGPDF['PDF_invoice914419aa32f04011357d3b604a86d7eb'] = 'Transportista';
$_LANGPDF['PDF_invoiceba794350deb07c0c96fe73bd12239059'] = 'Embalaje';
$_LANGPDF['PDF_invoice6f3455d187a23443796efdcbe044096b'] = 'Sin impuestos';

?>

==> prestashop-1.4.9.0.tbz: www/prestashop/translations/es/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF_invoicee0036b67b754e9f6442f9f9e6b200c33'] = 'Devolución nº ';
$_LANGPDF['PDF_invoice77c3e447f60541a1c346a08134078c7f'] = 'Vale de compra nº ';
$_LANGPDF['PDF_invoicecb5efbba6a6babef9082ca6976928ca7'] = 'Albarán nº ';
$_LANGPDF['PDF_invoicefe4da50838bb10dcbf1bf8dcd9b12ab5'] = 'Factura nº ';
$_LANGPDF['PDF_invoiceba160acb58001c904c57507da3689265'] = 'Pedido n°';
$_LANGPDF['PDF_invoice808a04117534f9dfb63b9accd7efc609'] = 'Oficinas:';
$_LANGPDF['PDF_invoicea54cedc1e053a70d4a6319feccf531ca'] = 'TELÉFONO:';
$_LANGPDF['PDF_invoice2babe53026309ed1bc4d26626dbaf9b3'] = 'Detalles:';
$_LANGPDF['PDF_invoice15b57bef332e7e0327d89fe93711a954'] = 'La versión electrónica de esta factura está disponible en su cuenta. Para acceder a ella, identifíquese en';
$_LANGPDF['PDF_invoiceb1fb57b55075a4a51cf83e44d0440358'] = 'nuestra Web usando su dirección de correo electrónico y contraseña (que creó cuando realizó su primer pedido).';
$_LANGPDF['PDF_invoiced98a07f84921b24ee30f86fd8cd85c3c'] = 'de';
$_LANGPDF['PDF_invoice88be9ea838e21273267409d76af3b284'] = 'Hemos accedido a su solicitud de devolución.';
$_LANGPDF['PDF_invoicedd0b8feb4eb6c389c284518f5683017c'] = 'Le recordamos que debemos recibir su devolución antes de';
$_LANGPDF['PDF_invoiceea62a2e28a800c367509773730120a67'] = 'días desde el momento en que recibió su pedido.';
$_LANGPDF['PDF_invoice3d2f834cf879baebfdbe52c1c14d9d53'] = 'Listado de artículos devueltos:';
$_LANGPDF['PDF_invoice9fad4fa5f3fa5caad9b506bbdd9f35d4'] = 'Referencia de devolución:';
$_LANGPDF['PDF_invoicefb902bc4807c307b9309f2b528b96f2b'] = 'RET';
$_LANGPDF['PDF_invoiceec9d9f81be48dabb74bcdad5312816af'] = 'Gracias por incluir este número en su paquete de devolución.';
$_LANGPDF['PDF_invoicefbbd47b7e45c0ad3fe0bf70539b5a2d4'] = 'RECUERDE:';
$_LANGPDF['PDF_invoicea3852e23346f6f1e29e1683991690af3'] = '- Todos los artículos deben devolverse en su embalaje original en buen estado y sin haber sido usados.';
$_LANGPDF['PDF_invoice0e9a828e54995e48083a072205493fb4'] = '- Por favor,  imprima este documento e introdúzcalo en su envío.';
$_LANGPDF['PDF_invoicead500469c8dc258dcebb89c9efe15de7'] = '- El paquete debe enviarse a la siguiente dirección:';
$_LANGPDF['PDF_invoice9f68b11daca41ccf9fdc9d2f69901c9c'] = 'Una vez recibamos su envío, le informaremos por correo electrónico y procederemos al reembolso de su dinero.';
$_LANGPDF['PDF_invoice2d0620950a4d96ae301ba7a98e528714'] = 'Indíquenos cualquier pregunta que le surja.';
$_LANGPDF['PDF_invoice25e12a86579549b9f88117615eb05e4b'] = 'Si no se respetan las condiciones de devolución,';
$_LANGPDF['PDF_invoicec896fe3f3895e8ef54194eec601b8f3c'] = 'nos reservamos el derecho de rechazar su envío o el reembolso.';
$_LANGPDF['PDF_invoiceb5a7adde1af5c87d7fd797b6245c2a39'] = 'Descripción';
$_LANGPDF['PDF_invoice63d5049791d9d79d86e9a108b0a999ca'] = 'Referencia';
$_LANGPDF['PDF_invoice03ab340b3f99e03cff9e84314ead38c0'] = 'Cant.';
$_LANGPDF['PDF_invoice396124314c5fd1fa5bf463274896dc80'] = 'No se ha definido ningún método de precio para este grupo';
$_LANGPDF['PDF_invoice065ab3a28ca4f16f55f103adc7d0226f'] = 'Entrega';
$_LANGPDF['PDF_invoice6bdf2efe1a99072849d4e87baee37dbe'] = 'Facturación';
$_LANGPDF['PDF_invoice60da3bd6867e3952ef0057a0772ea885'] = 'id del impuesto';
$_LANGPDF['PDF_invoice7b13afd12d6d91d52aa9f857d23f96ef'] = 'Proyecto de factura';
$_LANGPDF['PDF_invoiced1228f5476d15142b1358ae4b5fa2454'] = 'Pedido nº ';
$_LANGPDF['PDF_invoicef8617a92ba0a0a4eabee724eab7c9f48'] = 'Transportista:';
$_LANGPDF['PDF_invoicec1f6368d15f7c13c4e5e8f70c68c747f'] = 'Modo de pago:';
$_LANGPDF['PDF_invoicea3a79b28bc45b7fd393effd056b917e1'] = 'Fecha de envío:';
$_LANGPDF['PDF_invoice115dfa9ced2cf136ae677b9a389a5e60'] = 'paquete regalo';
$_LANGPDF['PDF_invoice2370a4958c4ebe6d6c8045cd49a6b392'] = 'Total productos sin IVA';
$_LANGPDF['PDF_invoiceebaee01719541f61281c16ba22ebbfde'] = 'Total productos (IVA incluido)';
$_LANGPDF['PDF_invoicea0eb2cd0b3deb5444102e9a82edae11e'] = 'Total productos';
$_LANGPDF['PDF_invoicef3e545fccad720e197b9ca3b8b658440'] = 'Total descuentos (IVA incluido)';
$_LANGPDF['PDF_invoice9cc000efe3e783af5bf114f2e6573156'] = 'Total embalaje';
$_LANGPDF['PDF_invoicef246a17c095de09e043cc1cb917481da'] = 'Total gastos de envío sin IVA:';
$_LANGPDF['PDF_invoicee93f43fa527c3534aeca987091d6c049'] = 'Total gastos de envío IVA incluído:';
$_LANGPDF['PDF_invoice96b0141273eabab320119c467cdcaf17'] = 'Total';
$_LANGPDF['PDF_invoice54732c5d0a3f0d597312b0ee55d71fca'] = '(IVA incluido)';
$_LANGPDF['PDF_invoiceac5831c7ec2fed92c7bb73e9962003a4'] = '(sin IVA)';
$_LANGPDF['PDF_invoiceafd42dfebce46ec93972b2e0cbb8b83f'] = 'Precio Un.';
$_LANGPDF['PDF_invoice1d744a9ad1dac20645cfc4a36b77323b'] = 'imagen';
$_LANGPDF['PDF_invoicec2808546f3e14d267d798f4e0e6f102e'] = 'Personalizado';
$_LANGPDF['PDF_invoicea1e7379abfdbc3b8e03506e5489c6110'] = 'Descuento:';
$_LANGPDF['PDF_invoicee7bbf027179f23c92bec649fa6ae78e4'] = 'Exento de IVA según el artículo 259B del Código General de los Impuestos.';
$_LANGPDF['PDF_invoice42c26bf38ece1dcd27aca8c6f8c076ed'] = 'Desglose IVA';
$_LANGPDF['PDF_invoice4b78ac8eb158840e9638a3aeb26c4a9d'] = 'Tasa';
$_LANGPDF['PDF_invoicecd6576cc33506a6c44e2debbde5c14d9'] = 'Total sin IVA';
$_LANGPDF['PDF_invoiceb602e0d0c6a72053d0a5be60cb2f8126'] = 'Total IVA';
$_LANGPDF['PDF_invoicefe1218d355367ae728ae5bf4bbf0019e'] = 'Ecotasa (IVA incl.)';
$_LANGPDF['PDF_invoiceae5c2883df7651730799e1036984a6a3'] = 'Total IVA incluído';
$_LANGPDF['PDF_invoice068f80c7519d0528fb08e82137a72131'] = 'Artículos';
$_LANGPDF['PDF_invoice914419aa32f04011357d3b604a86d7eb'] = 'Transportista';
$_LANGPDF['PDF_invoice41c1d61bfff3fc9b1fd8f195061b8caa'] = 'Embalaje';
$_LANGPDF['PDF_invoice6f3455d187a23443796efdcbe044096b'] = 'Sin impuestos';
